@@ -2,7 +2,9 @@
 from __future__ import print_function, absolute_import
 
 import humanize
+import inspect
 import json
+import logging
 import os
 import re
 import requests
@@ -28,12 +30,14 @@ CHECKPOINT_URL = 'http://passport.115.com/?ct=ajax&ac=ajax_check_point'
 
 
 class RequestsLWPCookieJar(cookielib.LWPCookieJar, RequestsCookieJar):
-    """RequestsCookieJar compatible LWPCookieJar"""
+    """:class:`requests.cookies.RequestsCookieJar` compatible
+    :class:`cookielib.LWPCookieJar`"""
     pass
 
 
 class RequestsMozillaCookieJar(cookielib.MozillaCookieJar, RequestsCookieJar):
-    """RequestsCookieJar compatible RequestsMozillaCookieJar"""
+    """:class:`requests.cookies.RequestsCookieJar` compatible
+    :class:`cookielib.MozillaCookieJar`"""
     pass
 
 
@@ -68,7 +72,7 @@ class RequestHandler(object):
         Send a formatted API request
 
         :param request: a formatted request object
-        :type request: :class:`Request`
+        :type request: :class:`.Request`
         """
         r = self.session.request(method=request.method,
                                  url=request.url,
@@ -91,7 +95,8 @@ class RequestHandler(object):
             except ValueError:
                 # No JSON-encoded data returned
                 if expect_json:
-                    print(r.content)
+                    logger = logging.getLogger(conf.LOGGING_API_LOGGER)
+                    logger.debug(r.content)
                     raise InvalidAPIAccess('Invalid API access.')
                 return Response(False, r.content)
         else:
@@ -120,6 +125,16 @@ class Request(object):
         self.data = data
         self.files = files
         self.headers = headers
+        self._debug()
+
+    def _debug(self):
+        logger = logging.getLogger(conf.LOGGING_API_LOGGER)
+        level = logger.getEffectiveLevel()
+        if level == logging.DEBUG:
+            func = inspect.stack()[2][3]
+            msg = conf.DEBUG_REQ_FMT % (func, self.url, self.method,
+                                        self.params, self.data)
+            logger.debug(msg)
 
 
 class Response(object):
@@ -133,6 +148,15 @@ class Response(object):
     def __init__(self, state, content):
         self.state = state
         self.content = content
+        self._debug()
+
+    def _debug(self):
+        logger = logging.getLogger(conf.LOGGING_API_LOGGER)
+        level = logger.getEffectiveLevel()
+        if level == logging.DEBUG:
+            func = inspect.stack()[4][3]
+            msg = conf.DEBUG_RES_FMT % (func, self.state, self.content)
+            logger.debug(msg)
 
 
 class API(object):
@@ -143,32 +167,40 @@ class API(object):
     :ivar http: :class:`.RequestHandler` object associated with this
         interface
     :cvar int num_tasks_per_page: default number of tasks per page/request
+    :cvar str web_api_url: files API url
+    :cvar str aps_natsort_url: natural sort files API url
+    :cvar str proapi_url: pro API url for downloads
     """
 
     num_tasks_per_page = 30
     web_api_url = 'http://web.api.115.com/files'
     aps_natsort_url = 'http://aps.115.com/natsort/files.php'
+    proapi_url = 'http://proapi.115.com/app/chrome/down'
 
-    def __init__(self, auto_logout=True, persistent=False,
+    def __init__(self, persistent=False,
                  cookies_filename=None, cookies_type='LWPCookieJar'):
         """
         :param bool auto_logout: whether to logout automatically when
             :class:`.API` object is destroyed
+
+                                 .. deprecated:: 0.6.0
+                                     Call :meth:`.API.logout` explicitly
+
         :param bool persistent: whether to use persistent session that stores
             cookies on disk
         :param str cookies_filename: path to the cookies file, use default
-            path (`~/.115cookies`) if none
+            path (`~/.115cookies`) if None
         :param str cookies_type: a string representing
             :class:`cookielib.FileCookieJar` subclass,
             `LWPCookieJar` (default) or `MozillaCookieJar`
         """
-        self.auto_logout = auto_logout
         self.persistent = persistent
         self.cookies_filename = cookies_filename
         self.cookies_type = cookies_type
         self.passport = None
         self.http = RequestHandler()
-        # Cached variabled to decrease API hits
+        self.logger = logging.getLogger(conf.LOGGING_API_LOGGER)
+        # Cache attributes to decrease API hits
         self._user_id = None
         self._username = None
         self._signatures = {}
@@ -176,19 +208,13 @@ class API(object):
         self._lixian_timestamp = None
         self._root_directory = None
         self._downloads_directory = None
+        self._receiver_directory = None
         self._torrents_directory = None
         self._task_count = None
         self._task_quota = None
         if self.persistent:
             self.load_cookies()
 
-    def __del__(self):
-        if self.auto_logout and self.has_logged_in:
-            self.logout()
-        if not self.auto_logout and self.has_logged_in:
-            if self.persistent:
-                self.save_cookies()
-
     def _reset_cache(self):
         self._user_id = None
         self._username = None
@@ -197,6 +223,7 @@ class API(object):
         self._lixian_timestamp = None
         self._root_directory = None
         self._downloads_directory = None
+        self._receiver_directory = None
         self._torrents_directory = None
         self._task_count = None
         self._task_quota = None
@@ -208,7 +235,7 @@ class API(object):
         self.cookies = cookies_class(f)
 
     def load_cookies(self, ignore_discard=True, ignore_expires=True):
-        """Load cookies from the file"""
+        """Load cookies from the file :attr:`.API.cookies_filename`"""
         self._init_cookies()
         if os.path.exists(self.cookies.filename):
             self.cookies.load(ignore_discard=ignore_discard,
@@ -216,7 +243,7 @@ class API(object):
             self._reset_cache()
 
     def save_cookies(self, ignore_discard=True, ignore_expires=True):
-        """Save cookies to the file"""
+        """Save cookies to the file :attr:`.API.cookies_filename`"""
         if not isinstance(self.cookies, cookielib.FileCookieJar):
             m = 'Cookies must be a cookielib.FileCookieJar object to be saved.'
             raise APIError(m)
@@ -225,12 +252,16 @@ class API(object):
 
     @property
     def cookies(self):
-        """Cookies getter shortcut"""
+        """
+        Cookies of the current API session (cookies getter shortcut)
+        """
         return self.http.session.cookies
 
     @cookies.setter
     def cookies(self, cookies):
-        """Cookies setter shortcut"""
+        """
+        Cookies of the current API session (cookies setter shortcut)
+        """
         self.http.session.cookies = cookies
 
     def login(self, username=None, password=None,
@@ -271,10 +302,20 @@ class API(object):
             raise AuthenticationError(msg)
 
     def get_user_info(self):
+        """
+        Get user info
+
+        :return: a dictionary of user information
+        :rtype: dict
+
+        """
         return self._req_get_user_aq()
 
     @property
     def user_id(self):
+        """
+        User id of the current API user
+        """
         if self._user_id is None:
             if self.has_logged_in:
                 self._user_id = self._req_get_user_aq()['data']['uid']
@@ -284,6 +325,9 @@ class API(object):
 
     @property
     def username(self):
+        """
+        Username of the current API user
+        """
         if self._username is None:
             if self.has_logged_in:
                 self._username = self._get_username()
@@ -321,6 +365,13 @@ class API(object):
             self._load_downloads_directory()
         return self._downloads_directory
 
+    @property
+    def receiver_directory(self):
+        """Parent directory of the downloads directory"""
+        if self._receiver_directory is None:
+            self._receiver_directory = self.downloads_directory.parent
+        return self._receiver_directory
+
     @property
     def torrents_directory(self):
         """Default directory that stores uploaded torrents"""
@@ -356,15 +407,15 @@ class API(object):
 
     def add_task_bt(self, filename, select=False):
         """
-        Added a new BT task
+        Add a new BT task
 
         :param str filename: path to torrent file to upload
         :param bool select: whether to select files in the torrent.
 
-            * If True, it returns the opened torrent (:class:`.Torrent`) and
+            * True: it returns the opened torrent (:class:`.Torrent`) and
                 can then iterate files in :attr:`.Torrent.files` and
-                select/unselect them before calling :func:`Torrent.submit`
-            * If False, it will submit the torrent with default selected files
+                select/unselect them before calling :meth:`.Torrent.submit`
+            * False: it will submit the torrent with default selected files
 
         """
         filename = eval_path(filename)
@@ -376,6 +427,8 @@ class API(object):
 
     def add_task_url(self, target_url):
         """
+        Add a new URL task
+
         :param str target_url: the URL of the file that to be downloaded
 
         """
@@ -402,7 +455,7 @@ class API(object):
 
         :param str filename: path to the file to upload
         :param directory: destionation :class:`.Directory`, defaults to
-            :class:`.API.downloads_directory` if None
+            :attribute:`.API.downloads_directory` if None
         :return: the uploaded file
         :rtype: :class:`.File`
         """
@@ -422,7 +475,7 @@ class API(object):
         return _instantiate_uploaded_file(self, data2)
 
     def download(self, obj, path=None, show_progress=True, resume=True,
-                 auto_retry=True):
+                 auto_retry=True, proapi=False):
         """
         Download a file
 
@@ -433,8 +486,10 @@ class API(object):
             identified by filename
         :param bool auto_retry: whether to retry automatically upon closed
             transfer until the file's download is finished
+        :param bool proapi: whether to use pro API
         """
-        download(obj.url, path=path, session=self.http.session,
+        url = obj.get_download_url(proapi)
+        download(url, path=path, session=self.http.session,
                  show_progress=show_progress, resume=resume,
                  auto_retry=auto_retry)
 
@@ -459,6 +514,80 @@ class API(object):
                 res.append(_instantiate_file(self, entry))
         return res
 
+    def move(self, entries, directory):
+        """
+        Move one or more entries (file or directory) to the destination
+        directory
+
+        :param list entries: a list of source entries (:class:`.BaseFile`
+            object)
+        :param directory: destination directory
+        :return: whether the action is successful
+        :raise: :class:`.APIError` if something bad happened
+        """
+        fcids = []
+        for entry in entries:
+            if isinstance(entry, File):
+                fcid = entry.fid
+            elif isinstance(entry, Directory):
+                fcid = entry.cid
+            else:
+                raise APIError('Invalid BaseFile instance for an entry.')
+            fcids.append(fcid)
+        if not isinstance(directory, Directory):
+            raise APIError('Invalid destination directory.')
+        if self._req_files_move(directory.cid, fcids):
+            for entry in entries:
+                if isinstance(entry, File):
+                    entry.cid = directory.cid
+                entry.reload()
+            return True
+        else:
+            raise APIError('Error moving entries.')
+
+    def edit(self, entry, name, mark=False):
+        """
+        Edit an entry (file or directory)
+
+        :param entry: :class:`.BaseFile` object
+        :param str name: new name for the entry
+        :param bool mark: whether to bookmark the entry
+        """
+        fcid = None
+        if isinstance(entry, File):
+            fcid = entry.fid
+        elif isinstance(entry, Directory):
+            fcid = entry.cid
+        else:
+            raise APIError('Invalid BaseFile instance for an entry.')
+        is_mark = 0
+        if mark is True:
+            is_mark = 1
+        if self._req_files_edit(fcid, name, is_mark):
+            entry.reload()
+            return True
+        else:
+            raise APIError('Error editing the entry.')
+
+    def mkdir(self, parent, name):
+        """
+        Create a directory
+
+        :param parent: the parent directory
+        :param str name: the name of the new directory
+        :return: the new directory
+        :rtype: :class:`.Directory`
+
+        """
+        pid = None
+        cid = None
+        if isinstance(parent, Directory):
+            pid = parent.cid
+        else:
+            raise('Invalid Directory instance.')
+        cid = self._req_files_add(pid, name)['cid']
+        return self._load_directory(cid)
+
     def _req_offline_space(self):
         """Required before accessing lixian tasks"""
         url = 'http://115.com/'
@@ -477,6 +606,10 @@ class API(object):
             raise RequestFailure(msg)
 
     def _req_lixian_task_lists(self, page=1):
+        """
+        This request will cause the system to create a default downloads
+        directory if it does not exist
+        """
         url = 'http://115.com/lixian/'
         params = {'ct': 'lixian', 'ac': 'task_lists'}
         self._load_signatures()
@@ -532,6 +665,8 @@ class API(object):
         if res.state:
             return res.content
         else:
+            msg = res.content.get('error_msg')
+            self.logger.error(msg)
             raise RequestFailure('Failed to open torrent.')
 
     def _req_lixian_add_task_bt(self, t):
@@ -557,7 +692,8 @@ class API(object):
         if res.state:
             return True
         else:
-            print(res.content.get('error_msg'))
+            msg = res.content.get('error_msg')
+            self.logger.error(msg)
             raise RequestFailure('Failed to create new task.')
 
     def _req_lixian_add_task_url(self, target_url):
@@ -576,7 +712,8 @@ class API(object):
         if res.state:
             return True
         else:
-            print(res.content.get('error_msg'))
+            msg = res.content.get('error_msg')
+            self.logger.error(msg)
             raise RequestFailure('Failed to create new task.')
 
     def _req_lixian_task_del(self, t):
@@ -602,11 +739,11 @@ class API(object):
                                snap=0, natsort=1, source=None, type=0,
                                format='json', star=None, is_share=None):
         """
-        When :func:`API._req_files` is called with `o='filename'` and
+        When :meth:`.API._req_files` is called with `o='filename'` and
             `natsort=1`, API access will fail
-            and :func:`API._req_aps_natsort_files` is subsequently called with
+            and :meth:`.API._req_aps_natsort_files` is subsequently called with
             the same kwargs. Refer to the implementation in
-            :func:`Directory.list`
+            :meth:`.Directory.list`
         """
         params = locals()
         del params['self']
@@ -665,14 +802,14 @@ class API(object):
         req = Request(method='POST', url=url, data=data)
         res = self.http.send(req)
         if res.state:
-            return res.content
+            return True
         else:
             raise RequestFailure('Failed to access files API.')
 
     def _req_files_add(self, pid, cname):
         """
         Add a directory
-        :param int pid: parent directory id
+        :param str pid: parent directory id
         :param str cname: directory name
         """
         url = self.web_api_url + '/add'
@@ -688,7 +825,7 @@ class API(object):
     def _req_files_move(self, pid, fids):
         """
         Move files or directories
-        :param int pid: target directory id
+        :param str pid: destination directory id
         :param list fids: a list of ids of files or directories to be moved
         """
         url = self.web_api_url + '/move'
@@ -699,7 +836,7 @@ class API(object):
         req = Request(method='POST', url=url, data=data)
         res = self.http.send(req)
         if res.state:
-            return res.content
+            return True
         else:
             raise RequestFailure('Failed to access files API.')
 
@@ -730,13 +867,21 @@ class API(object):
         else:
             raise RequestFailure('No directory found.')
 
-    def _req_files_download_url(self, pickcode):
-        url = self.web_api_url + '/download'
-        params = {'pickcode': pickcode, '_': get_timestamp(13)}
+    def _req_files_download_url(self, pickcode, proapi=False):
+        if not proapi:
+            url = self.web_api_url + '/download'
+            params = {'pickcode': pickcode, '_': get_timestamp(13)}
+        else:
+            url = self.proapi_url
+            params = {'pickcode': pickcode, 'method': 'get_file_url'}
         req = Request(method='GET', url=url, params=params)
         res = self.http.send(req)
         if res.state:
-            return res.content['file_url']
+            if not proapi:
+                return res.content['file_url']
+            else:
+                fid = res.content['data'].keys()[0]
+                return res.content['data'][fid]['url']['url']
         else:
             raise RequestFailure('Failed to get download URL.')
 
@@ -791,7 +936,7 @@ class API(object):
             if 'errno' in res.content:
                 if res.content['errno'] == 990005:
                     raise JobError()
-            print(res.content['error'])
+            self.logger.error(res.content['error'])
             raise APIError(msg)
 
     def _req_get_user_aq(self):
@@ -872,7 +1017,7 @@ class API(object):
         soup = BeautifulSoup(r.content)
         scripts = [script.text for script in soup.find_all('script')]
         text = '\n'.join(scripts)
-        pattern = "%s = (.*);" % (variable.upper())
+        pattern = "%s\s*=\s*(.*);" % (variable.upper())
         m = re.search(pattern, text)
         if not m:
             msg = 'Cannot parse source JavaScript for %s.' % variable
@@ -956,9 +1101,11 @@ class BaseFile(Base):
     def __init__(self, api, cid, name):
         """
         :param API api: associated API object
-        :param int cid: integer
-            for file: this represents the directory it belongs to;
-            for directory: this represents itself
+        :param str cid: directory id
+
+            * For file: this represents the directory it belongs to;
+            * For directory: this represents itself
+
         :param str name: originally named `n`
 
         NOTICE
@@ -996,11 +1143,42 @@ class BaseFile(Base):
         else:
             raise APIError('This file or directory is already deleted.')
 
+    def move(self, directory):
+        """
+        Move this file or directory to the destination directory
+
+        :param directory: destination directory
+        :return: whether the action is successful
+        :raise: :class:`.APIError` if something bad happened
+        """
+        self.api.move([self], directory)
+
+    def edit(self, name, mark=False):
+        """
+        Edit this file or directory
+
+        :param str name: new name for this entry
+        :param bool mark: whether to bookmark this entry
+        """
+        self.api.edit(self, name, mark)
+
     @property
     def is_deleted(self):
         """Whether this file or directory is deleted"""
         return self._deleted
 
+    def __eq__(self, other):
+        if isinstance(self, File):
+            if isinstance(other, File):
+                return self.fid == other.fid
+        elif isinstance(self, Directory):
+            if isinstance(other, Directory):
+                return self.cid == other.cid
+        return False
+
+    def __ne__(self, other):
+        return not self.__eq__(other)
+
     def __unicode__(self):
         return self.name
 
@@ -1010,7 +1188,7 @@ class File(BaseFile):
     File in a directory
 
     :ivar int fid: file id
-    :ivar int cid: cid of the current directory
+    :ivar str cid: cid of the current directory
     :ivar int size: size in bytes
     :ivar str size_human: human-readable size
     :ivar str file_type: originally named `ico`
@@ -1044,22 +1222,28 @@ class File(BaseFile):
             self._directory = self.api._load_directory(self.cid)
         return self._directory
 
-    def get_download_url(self):
-        """Get this file's download URL"""
+    def get_download_url(self, proapi=False):
+        """
+        Get this file's download URL
+
+        :param bool proapi: whether to use pro API
+
+        """
         if self._download_url is None:
             self._download_url = \
-                self.api._req_files_download_url(self.pickcode)
+                self.api._req_files_download_url(self.pickcode, proapi)
         return self._download_url
 
     @property
     def url(self):
-        """Alias for :func:`File.get_download_url`"""
+        """Alias for :meth:`.File.get_download_url` with `proapi=False`"""
         return self.get_download_url()
 
     def download(self, path=None, show_progress=True, resume=True,
-                 auto_retry=True):
+                 auto_retry=True, proapi=False):
         """Download this file"""
-        self.api.download(self, path, show_progress, resume, auto_retry)
+        self.api.download(self, path, show_progress, resume, auto_retry,
+                          proapi)
 
     @property
     def is_torrent(self):
@@ -1076,11 +1260,26 @@ class File(BaseFile):
         if self.is_torrent:
             return self.api._load_torrent(self)
 
+    def reload(self):
+        """
+        Reload file info and metadata
+
+        * name
+        * sha
+        * pickcode
+
+        """
+        res = self.api._req_file(self.fid)
+        data = res['data'][0]
+        self.name = data['file_name']
+        self.sha = data['sha1']
+        self.pickcode = data['pick_code']
+
 
 class Directory(BaseFile):
     """
-    :ivar int cid: cid of this directory
-    :ivar int pid: represents the parent directory it belongs to
+    :ivar str cid: cid of this directory
+    :ivar str pid: represents the parent directory it belongs to
     :ivar int count: number of entries in this directory
     :ivar datetime.datetime date_created: integer, originally named `t`
     :ivar str pickcode: string, originally named `pc`
@@ -1139,8 +1338,8 @@ class Directory(BaseFile):
         """
         Load entries
 
-        :param function func: function (:func:`API._req_files` or
-            :func:`API._req_search`) that returns entries
+        :param function func: function (:meth:`.API._req_files` or
+            :meth:`.API._req_search`) that returns entries
         :param int count: number of entries to load. This value should never
             be greater than self.count
         :param int page: page number (starting from 1)
@@ -1155,7 +1354,8 @@ class Directory(BaseFile):
         loaded_entries = [
             entry for entry in res['data'][:count]
         ]
-        total_count = res['count']
+        #total_count = res['count']
+        total_count = self.count
         # count should never be greater than total_count
         if count > total_count:
             count = total_count
@@ -1183,6 +1383,7 @@ class Directory(BaseFile):
         """
         if self.cid is None:
             return False
+        self.reload()
         kwargs = {}
         # `cid` is the only required argument
         kwargs['cid'] = self.cid
@@ -1190,6 +1391,18 @@ class Directory(BaseFile):
         kwargs['show_dir'] = 1 if show_dir is True else 0
         kwargs['natsort'] = 1 if natsort is True else 0
         kwargs['o'] = order
+
+        # When the downloads directory exists, its parent directory's count
+        # does not include the downloads directory. This behavior is similar
+        # to the parent's parent (root).
+        # The following code fixed this behavior so that a directory's
+        # count correctly reflects the actual number of entries in it
+        # The side-effect that this code may ensure that downloads directory
+        # exists.
+
+        if self.is_root or self == self.api.receiver_directory:
+            self._count += 1
+
         if self.count <= count:
             # count should never be greater than self.count
             count = self.count
@@ -1212,12 +1425,23 @@ class Directory(BaseFile):
                 res.append(_instantiate_file(self.api, entry))
         return res
 
+    def mkdir(self, name):
+        """
+        Create a new directory in this directory
+        """
+        self.api.mkdir(self, name)
 
-class Task(Directory):
+
+class Task(Base):
     """
     BitTorrent or URL task
 
     :ivar datetime.datetime add_time: added time
+    :ivar str cid: associated directory id, if any. For a directory task (
+        e.g. BT task), this is its associated directory's cid. For a file
+        task (e.g. HTTP url task), this is the cid of the downloads directory.
+        This value may be None if the task is failed and has no corresponding
+        directory
     :ivar str file_id: equivalent to `cid` of :class:`.Directory`. This value
         may be None if the task is failed and has no corresponding directory
     :ivar str info_hash: hashed value
@@ -1248,8 +1472,9 @@ class Task(Directory):
     def __init__(self, api, add_time, file_id, info_hash, last_update,
                  left_time, move, name, peers, percent_done, rate_download,
                  size, status, cid, pid):
-        super(Task, self).__init__(api, cid, name, pid)
-
+        self.api = api
+        self.cid = cid
+        self.name = name
         self.add_time = add_time
         self.file_id = file_id
         self.info_hash = info_hash
@@ -1266,6 +1491,19 @@ class Task(Directory):
         self._deleted = False
         self._count = -1
 
+    @property
+    def is_directory(self):
+        """
+        :return: whether this task is associated with a directory
+        :rtype: bool
+        """
+        return self.api.downloads_directory.cid != self.cid
+
+    @property
+    def is_bt(self):
+        """Alias of `is_directory`"""
+        return self.is_directory
+
     def delete(self):
         """
         Delete task (does not influence its corresponding directory)
@@ -1281,6 +1519,10 @@ class Task(Directory):
 
     @property
     def is_deleted(self):
+        """
+        :return: whether this task is deleted
+        :rtype: bool
+        """
         return self._deleted
 
     @property
@@ -1332,29 +1574,33 @@ class Task(Directory):
 
     @property
     def directory(self):
-        """Corresponding directory to this task"""
+        """Associated directory, if any, with this task"""
+        if not self.is_directory:
+            msg = 'This task is a file task with no associated directory.'
+            raise TaskError(msg)
         if self._directory is None:
             if self.is_transferred:
                 self._directory = self.api._load_directory(self.cid)
         if self._directory is None:
-            msg = 'No directory corresponding to this task: Task is %s.' % \
+            msg = 'No directory assciated with this task: Task is %s.' % \
                 self.status_human.lower()
             raise TaskError(msg)
         return self._directory
 
     @property
     def parent(self):
-        """Parent directory of the corresponding directory"""
+        """Parent directory of the associated directory"""
         return self.directory.parent
 
     @property
     def count(self):
-        """Number of entries in the corresponding directory"""
+        """Number of entries in the associated directory"""
         return self.directory.count
 
-    def list(self, count=30, order='user_ptime', asc=False, show_dir=True):
+    def list(self, count=30, order='user_ptime', asc=False, show_dir=True,
+             natsort=True):
         """
-        List files of the corresponding directory to this task.
+        List files of the associated directory to this task.
 
         :param int count: number of entries to be listed
         :param str order: originally named `o`
@@ -1362,7 +1608,10 @@ class Task(Directory):
         :param bool show_dir: whether to show directories
 
         """
-        return self.directory.list(count, order, asc, show_dir)
+        return self.directory.list(count, order, asc, show_dir, natsort)
+
+    def __unicode__(self):
+        return self.name
 
 
 class Torrent(Base):
@@ -1403,7 +1652,7 @@ class Torrent(Base):
 
     @property
     def unselected_files(self):
-        """List of unselected :class:`TorrentFile` objects of this torrent"""
+        """List of unselected :class:`.TorrentFile` objects of this torrent"""
         return [f for f in self.files if not f.selected]
 
     def __unicode__(self):
@@ -1429,9 +1678,11 @@ class TorrentFile(Base):
         self.selected = selected
 
     def select(self):
+        """Select this file"""
         self.selected = True
 
     def unselect(self):
+        """Unselect this file"""
         self.selected = False
 
     def __unicode__(self):
